<?xml version="1.0"?>
<xsl:stylesheet 
  version='1.0' 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exslt="http://exslt.org/common"
  xmlns:math="http://exslt.org/math"
  extension-element-prefixes="exslt math">
  
  <!-- Print only the day portion of security version date. -->
  <xsl:template match="installedversion|currentversion">
  
    <xsl:value-of select="substring(., 1, 10)"/>
    
  </xsl:template>

  <!-- Expand a size with units. -->
  <xsl:template name="expand">
    <xsl:param name="number"/>
    
    <xsl:choose>
      <xsl:when test="$number/@units = 'PB'">
        <xsl:value-of select="$number * 1024 * 1024 * 1024 * 1024 * 1024"/>
      </xsl:when>
      <xsl:when test="$number/@units = 'TB'">
        <xsl:value-of select="$number * 1024 * 1024 * 1024 * 1024"/>
      </xsl:when>
      <xsl:when test="$number/@units = 'GB'">
        <xsl:value-of select="$number * 1024 * 1024 * 1024"/>
      </xsl:when>
      <xsl:when test="$number/@units = 'MB'">
        <xsl:value-of select="$number * 1024 * 1024"/>
      </xsl:when>
      <xsl:when test="$number/@units = 'KB'">
        <xsl:value-of select="$number * 1024"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$number"/>
      </xsl:otherwise>
    </xsl:choose>
    
  </xsl:template>
      
  <!-- Print a plural value. -->
  <xsl:template match="*" mode="plural">
  
    <xsl:call-template name="plural">
      <xsl:with-param name="key" select="local-name()"/>
      <xsl:with-param name="value" select="text()"/>
    </xsl:call-template>
    
  </xsl:template>
  
  <xsl:template name="plural">
    <xsl:param name="keys" select="$strings"/>
    <xsl:param name="key"/>
    <xsl:param name="value"/>
    
    <xsl:choose>
    
      <xsl:when test="$value = 0">
        <xsl:variable name="id" select="concat($key, '_none')"/>
        
        <xsl:call-template name="format">
          <xsl:with-param name="format">
            <xsl:value-of select="$keys/*[local-name() = $id]"/>
          </xsl:with-param>
          <xsl:with-param name="value">
            <xsl:value-of select="$value"/>
          </xsl:with-param>
        </xsl:call-template>
        
      </xsl:when>

      <xsl:when test="$value = 1">
        <xsl:variable name="id" select="concat($key, '_one')"/>
        
        <xsl:call-template name="format">
          <xsl:with-param name="format">
            <xsl:value-of select="$keys/*[local-name() = $id]"/>
          </xsl:with-param>
          <xsl:with-param name="value">
            <xsl:value-of select="$value"/>
          </xsl:with-param>
        </xsl:call-template>
        
      </xsl:when>

      <xsl:otherwise>
        <xsl:variable name="id" select="concat($key, '_other')"/>
        
        <xsl:call-template name="format">
          <xsl:with-param name="format">
            <xsl:value-of select="$keys/*[local-name() = $id]"/>
          </xsl:with-param>
          <xsl:with-param name="value">
            <xsl:value-of select="$value"/>
          </xsl:with-param>
        </xsl:call-template>
        
      </xsl:otherwise>
      
    </xsl:choose>
    
  </xsl:template>
  
  <!-- Perform a string format. -->
  <xsl:template name="format">
    <xsl:param name="format"/>
    <xsl:param name="value"/>
    
    <xsl:variable name="params" select="exslt:node-set($value)"/>

    <xsl:choose>
     
      <xsl:when test="contains($format, '%@')">
        <xsl:value-of select="substring-before($format, '%@')"/>
        <xsl:apply-templates select="$params[position() = 1]"/>
        
        <xsl:choose>
        
          <xsl:when test="count($value) &gt; 1">
          
            <xsl:call-template name="format">
              <xsl:with-param 
                name="format" select="substring-after($format, '%@')"/>
              <xsl:with-param 
                name="value" select="$value[position() &gt; 1]"/>
            </xsl:call-template>
            
          </xsl:when>
          
          <xsl:otherwise>
          
            <xsl:value-of select="substring-after($format, '%@')"/>
          
          </xsl:otherwise>
          
        </xsl:choose>
          
      </xsl:when>
      
      <xsl:otherwise>
        <xsl:value-of select="$format"/>
      </xsl:otherwise>
      
    </xsl:choose> 

  </xsl:template>
  
  <!-- Print a size with units. -->
  <xsl:template match="*" mode="units">
  
    <xsl:call-template name="units">
      <xsl:with-param name="value" select="."/>
    </xsl:call-template>
    
  </xsl:template>
  
  <!-- Print a boolean -->
  <xsl:template match="*[@type = 'boolean']">
    
    <xsl:variable name="value" select="."/>
    
    <xsl:value-of select="$strings/boolean/value[@key = $value]"/>
    
  </xsl:template>

  <xsl:template name="units">
    <xsl:param name="value"/>
  
    <xsl:variable name="units" select="$value/@units"/>

    <xsl:value-of select="$value"/>
    <xsl:text> </xsl:text>
    <xsl:value-of select="$strings/units/value[@key = $units]"/>
    
  </xsl:template>

</xsl:stylesheet>
